"""Module for command line interface.

　CLIまわりの処理
    - コマンドライン引数の解析・チェック
"""

import argparse
import core


def _validate_args(path):
    """
    Check whether the specified argument is valid or not.
    """
    if path is None:
        err_msg = (
            "A path is not specified in the argument. " "Please set the `-p` or `--path` argument."
        )
        raise Exception(err_msg)


def _exec_rctools(path, config_path):
    """
    Execute rctools Lint function.
    """
    info_list = core.check_text(text_file_path=path, config_file_path=config_path)
    return info_list


def main(args=None):
    """
    The function of command line entry point.
    """
    description = """SONY Ready Check Tools for patent documents
to be translated by Machine Translating."""
    parser = argparse.ArgumentParser(description=description)
    parser.add_argument(
        "-p", "--path", type=str, help="Text file path to be checked by ready-check-tool"
    )
    parser.add_argument("-c", "--config", type=str, help="JSON Config file path")

    if args is not None:
        args = parser.parse_args()

    _validate_args(path=args.path)
    _exec_rctools(path=args.path, config_path=args.config)
